@@ -1,5 +1,5 @@
 define('io.ox.saml/handlers', ['io.ox/core/extensions'], function (ext) {
-    function RedirectHandler (options) {
+    function RedirectHandler(options) {
         options = options || {};
 
         _.extend(this, options, {
@@ -7,10 +7,11 @@ define('io.ox.saml/handlers', ['io.ox/core/extensions'], function (ext) {
             handle: function (baton) {
                 var uri = baton.data.redirect_uri;
                 if (uri) {
+                    baton.handled = $.Deferred();
                     if ((/^http/i).test(uri)) {
                         window.location = uri;
-                        _.defer(function() {
-                            if (window.location != uri) return;
+                        _.defer(function () {
+                            if (window.location.href !== uri) return;
                             window.location.reload();
                         });
                     } else {
@@ -21,10 +22,12 @@ define('io.ox.saml/handlers', ['io.ox/core/extensions'], function (ext) {
                             path = '/' + uri;
                         }
 
-                        var l = location;
-                        window.location = l.protocol + '//' + l.host + path;
-                        _.defer(function() {
-                            if (window.location != uri) return;
+                        var proto = window.location.protocol,
+                            host = window.location.host;
+                        uri = proto + '//' + host + path;
+                        window.location = uri;
+                        _.defer(function () {
+                            if (window.location.href !== uri) return;
                             window.location.reload();
                         });
                     }
@@ -36,4 +39,4 @@ define('io.ox.saml/handlers', ['io.ox/core/extensions'], function (ext) {
     ext.point('io.ox.saml/relogin').extend(new RedirectHandler());
     ext.point('io.ox.saml/logout').extend(new RedirectHandler());
     ext.point('io.ox.saml/login').extend(new RedirectHandler());
-});
\ No newline at end of file
+});
